@@ -8,6 +8,6 @@
 from swf.models.decision.marker import MarkerDecision
 from swf.models.decision.task import ActivityTaskDecision
 from swf.models.decision.timer import TimerDecision
-from swf.models.decision.workflow import WorkflowExecutionDecision,\
-                                         ChildWorkflowExecutionDecision,\
-                                         ExternalWorkflowExecutionDecision
\ No newline at end of file
+from swf.models.decision.workflow import (WorkflowExecutionDecision,
+                                          ChildWorkflowExecutionDecision,
+                                          ExternalWorkflowExecutionDecision)
